DriveKitTripSimulator class

The main class of the plugin. This class provides methods to interact with the DriveKit TripSimulator SDK.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start(PresetTrip presetTrip) Future<void>
Starts trip simulation with a preset trip
stop() Future<void>
Stops trip simulation
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance DriveKitTripSimulator
unique instance of the DriveKitTripSimulator
no setter