PresetTrip enum

Preset trip enumeration used for trip simulation

Inheritance
Available extensions

Values

shortTrip → const PresetTrip

Trip too short that does not allow to rate the driver's behavior

mixedTrip → const PresetTrip

A 15-minute mixed trip in urban and suburban areas

cityTrip → const PresetTrip

A 20-minute city trip

suburbanTrip → const PresetTrip

A 30-minute trip performed in a suburban environment mostly

highwayTrip → const PresetTrip

A 55-minute highway trip

trainTrip → const PresetTrip

Trip recorded in a train

boatTrip → const PresetTrip

Trip recorded in a bus

busTrip → const PresetTrip

Trip recorded in a boat

tripWithCrashConfirmed40KmH → const PresetTrip

A short trip with a collision at 40 km/h that occurs 132 seconds after the trip begins and that corresponds to a confirmed accident

tripWithCrashConfirmed30KmH → const PresetTrip

A short trip with a collision at 30 km/h that occurs 137 seconds after the trip begins and that corresponds to a confirmed accident

tripWithCrashConfirmed20KmH → const PresetTrip

A short trip with a collision at 20 km/h that occurs 141 seconds after the trip begins and that corresponds to a confirmed accident

tripWithCrashUnconfirmed0KmH → const PresetTrip

A short trip with a collision during a vehicle stop that occurs 159 seconds after the trip begins and that corresponds to an unconfirmed accident

tripWithCrashConfirmed30KmHStillDriving → const PresetTrip

A trip to with a collision at 30km/h that occures 95 seconds after the trip begins and that corresponds to a confirmed accident, after which the driver continue driving.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<PresetTrip>
A constant List of the values in this enum, in order of their declaration.